/*******************************************************************************
* File Name: ECS.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_ECS_H) /* Pins ECS_H */
#define CY_PINS_ECS_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "ECS_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 ECS__PORT == 15 && ((ECS__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    ECS_Write(uint8 value);
void    ECS_SetDriveMode(uint8 mode);
uint8   ECS_ReadDataReg(void);
uint8   ECS_Read(void);
void    ECS_SetInterruptMode(uint16 position, uint16 mode);
uint8   ECS_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the ECS_SetDriveMode() function.
     *  @{
     */
        #define ECS_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define ECS_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define ECS_DM_RES_UP          PIN_DM_RES_UP
        #define ECS_DM_RES_DWN         PIN_DM_RES_DWN
        #define ECS_DM_OD_LO           PIN_DM_OD_LO
        #define ECS_DM_OD_HI           PIN_DM_OD_HI
        #define ECS_DM_STRONG          PIN_DM_STRONG
        #define ECS_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define ECS_MASK               ECS__MASK
#define ECS_SHIFT              ECS__SHIFT
#define ECS_WIDTH              1u

/* Interrupt constants */
#if defined(ECS__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in ECS_SetInterruptMode() function.
     *  @{
     */
        #define ECS_INTR_NONE      (uint16)(0x0000u)
        #define ECS_INTR_RISING    (uint16)(0x0001u)
        #define ECS_INTR_FALLING   (uint16)(0x0002u)
        #define ECS_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define ECS_INTR_MASK      (0x01u) 
#endif /* (ECS__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define ECS_PS                     (* (reg8 *) ECS__PS)
/* Data Register */
#define ECS_DR                     (* (reg8 *) ECS__DR)
/* Port Number */
#define ECS_PRT_NUM                (* (reg8 *) ECS__PRT) 
/* Connect to Analog Globals */                                                  
#define ECS_AG                     (* (reg8 *) ECS__AG)                       
/* Analog MUX bux enable */
#define ECS_AMUX                   (* (reg8 *) ECS__AMUX) 
/* Bidirectional Enable */                                                        
#define ECS_BIE                    (* (reg8 *) ECS__BIE)
/* Bit-mask for Aliased Register Access */
#define ECS_BIT_MASK               (* (reg8 *) ECS__BIT_MASK)
/* Bypass Enable */
#define ECS_BYP                    (* (reg8 *) ECS__BYP)
/* Port wide control signals */                                                   
#define ECS_CTL                    (* (reg8 *) ECS__CTL)
/* Drive Modes */
#define ECS_DM0                    (* (reg8 *) ECS__DM0) 
#define ECS_DM1                    (* (reg8 *) ECS__DM1)
#define ECS_DM2                    (* (reg8 *) ECS__DM2) 
/* Input Buffer Disable Override */
#define ECS_INP_DIS                (* (reg8 *) ECS__INP_DIS)
/* LCD Common or Segment Drive */
#define ECS_LCD_COM_SEG            (* (reg8 *) ECS__LCD_COM_SEG)
/* Enable Segment LCD */
#define ECS_LCD_EN                 (* (reg8 *) ECS__LCD_EN)
/* Slew Rate Control */
#define ECS_SLW                    (* (reg8 *) ECS__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define ECS_PRTDSI__CAPS_SEL       (* (reg8 *) ECS__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define ECS_PRTDSI__DBL_SYNC_IN    (* (reg8 *) ECS__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define ECS_PRTDSI__OE_SEL0        (* (reg8 *) ECS__PRTDSI__OE_SEL0) 
#define ECS_PRTDSI__OE_SEL1        (* (reg8 *) ECS__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define ECS_PRTDSI__OUT_SEL0       (* (reg8 *) ECS__PRTDSI__OUT_SEL0) 
#define ECS_PRTDSI__OUT_SEL1       (* (reg8 *) ECS__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define ECS_PRTDSI__SYNC_OUT       (* (reg8 *) ECS__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(ECS__SIO_CFG)
    #define ECS_SIO_HYST_EN        (* (reg8 *) ECS__SIO_HYST_EN)
    #define ECS_SIO_REG_HIFREQ     (* (reg8 *) ECS__SIO_REG_HIFREQ)
    #define ECS_SIO_CFG            (* (reg8 *) ECS__SIO_CFG)
    #define ECS_SIO_DIFF           (* (reg8 *) ECS__SIO_DIFF)
#endif /* (ECS__SIO_CFG) */

/* Interrupt Registers */
#if defined(ECS__INTSTAT)
    #define ECS_INTSTAT            (* (reg8 *) ECS__INTSTAT)
    #define ECS_SNAP               (* (reg8 *) ECS__SNAP)
    
	#define ECS_0_INTTYPE_REG 		(* (reg8 *) ECS__0__INTTYPE)
#endif /* (ECS__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_ECS_H */


/* [] END OF FILE */
