/*******************************************************************************
* File Name: ETH_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ETH_PVT.h"

static ETH_BACKUP_STRUCT ETH_backup =
{
    ETH_DISABLED,
    ETH_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: ETH_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ETH_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: ETH_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ETH_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: ETH_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_Sleep(void) 
{
    /* Save components enable state */
    ETH_backup.enableState = ((uint8) ETH_IS_ENABLED);

    ETH_Stop();
}


/*******************************************************************************
* Function Name: ETH_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ETH_backup - used when non-retention registers are restored.
*  ETH_txBufferWrite - modified every function call - resets to
*  zero.
*  ETH_txBufferRead - modified every function call - resets to
*  zero.
*  ETH_rxBufferWrite - modified every function call - resets to
*  zero.
*  ETH_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ETH_Wakeup(void) 
{
    #if(ETH_RX_SOFTWARE_BUF_ENABLED)
        ETH_rxBufferFull  = 0u;
        ETH_rxBufferRead  = 0u;
        ETH_rxBufferWrite = 0u;
    #endif /* (ETH_RX_SOFTWARE_BUF_ENABLED) */

    #if(ETH_TX_SOFTWARE_BUF_ENABLED)
        ETH_txBufferFull  = 0u;
        ETH_txBufferRead  = 0u;
        ETH_txBufferWrite = 0u;
    #endif /* (ETH_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    ETH_ClearFIFO();

    /* Restore components block enable state */
    if(0u != ETH_backup.enableState)
    {
        ETH_Enable();
    }
}


/* [] END OF FILE */
