/*
 * Author: Lars Randers <lranders@mail.dk>
 */
#include <device.h>
#include <stdio.h>
#include <enc28j60.h>
#include <lwip/init.h>
#include <lwip/netif.h>
#include <lwip/dhcp.h>
#include <lwip/tcp_impl.h>
#include <netif/etharp.h>
#include <httpserver_raw/httpd.h>
#include <crc16.h>
#include <eeprom.h>
#include <lwip/raw.h>//

#include <MyISRs.h>

//uint8 Table[1024]={0};
uint8 Table[2233]={
"Vided into di®erent processes.   One process model that has been used to implement communication 11otocols is to let each protocol run as a stand alone process. With this model, a strict protocol layering is enforced, and the communication points between the protocols must be strictly de?ned. While this approach has its advantages such as protocols can be added at runtime, understanding the code and debugging is generally easier, there are also disadvantages. The strict layering is not, as described earlier, always the best way to implement protocols. Also, and more important, for each layer crossed, a context switch must be made. For an incoming TCP segment this would mean three context switches, from the device driver for the network interface, to the IP process, to the TCP process and ?nally to the application process. In most operating systems a context switch is fairly expensive. Another common approach is to let the communication protocols reside in the kernel of the operating system. In the case of a kernel implementation of the communication protocols, the application processes communicate with the protocols through system calls. The communication protocols are not strictly divided from each other but may use the techniques of crossing the protocol layering. lwIP uses a process model in which all protocols reside in a single process and are thus sep-arated from the operating system kernel. Application programs may either reside in the lwIP process, or be in separate processes. Communication between the TCP/IP stack and the applica-tion programs are done either by function calls for the case where the application program shares a process with lwIP, or by the means of a more abstract API. Having lwIP implemented as a user space process rather than in the operating system kernel has both its advantages and disadvantages. The main advantage of having lwIP as a process is that is portable across di®erent operating systems. Since lwIP is designed to run in small operating systems that generally do not support neither swapping out processes not virtual memory, the delay caused by having to wait for disk activity if part of the lwIP process is swapped or paged out to disk will not be a problem."
};
volatile unsigned char g_ucFlags = 0;
volatile unsigned long g_ulTickCounter = 0;
volatile unsigned long g_ulIntCounter = 0;

#define FLAG_USE_DHCP    5

//Timewheel is set at 20Hz, thus producing a tick every 50ms
#define TICK_MS 50

const epmLayout_t epmSaneValues = {
	.macAddress = {0x00,0x0d,0x65,0x2a,0x84,0x80},
	.ipAddress = {192,168,0,220},
	.netMask = {255,255,255,0},
	.gateWay = {192,168,0,1},
//	.u.bits.useDhcp = 1
     .u.bits.useDhcp = 0
};

#define HB_RESET 186000
uint32_t hb_counter = HB_RESET;
err_t Test;

void heartbeat(void)
{
	if(--hb_counter == 0) {
		HB_Write(~HB_Read());
		hb_counter = HB_RESET;
	}
}

//Convenience macro for readability
#define EPM(member) ((epmLayout_t *)epm)->member

/////////////////////////////////////////////// //////////////////////////////////////////////////////
err_t sent_callback(void *arg, struct tcp_pcb *tpcb, u16_t len)//************************************************************
{
static int i;
int BUFSIZE = 1024;

/* if connection is closed, or there is no data to send */
if (tpcb->state > ESTABLISHED) {
return ERR_OK;
}

if(i>2)
{
i=0;
return ERR_OK;
//tcp_close(tpcb);
}
i++;
tcp_write(tpcb, &Table[(len)], len, 1);


return ERR_OK;
}

static err_t recv_callback(void *arg, struct tcp_pcb *pcb, struct pbuf *p, err_t err)//*************************************** 
{
    /* indicate that the packet has been received */
    tcp_recved(pcb, p->len);    // пакет принят
    //pbuf_free(p);
    tcp_write(pcb, Table, 1000, 0);  //+++++++++++++++++++++++++++++++  

    return ERR_OK;
}
///..........................................................................................
  
 static err_t accept_callback(void *arg, struct tcp_pcb *pcb, err_t err)//******************************************* 
{
   /* keep a count of connection # */
    //tcp_arg(pcb, (void*)palloc_arg()); 
    tcp_recv(pcb, recv_callback);//  tcp_recv Используется для указания функции, которая будет вызываться, когда соединение TCP получает данные.
    tcp_sent(pcb, sent_callback);//   callback функция, которая будет вызываться, когда данные успешно были получены  удаленным хостом 
    
    return ERR_OK;
}
///..........................................................................................
static struct tcp_pcb *pcb;
//#define LWIP_PLATFORM_DIAG(msg) do {printf msg;} while(0)
///..........................................................................................


void tcp_init_func(void)  //************************************************************************************************
{
    /* Create a new TCP PCB. */
    pcb = tcp_new();    //protocol control block
    /* Bind the PCB to TCP port 10000. */
    err_t res;
    //res = tcp_bind(pcb, NULL, 10000);
    res = tcp_bind(pcb, IP_ADDR_ANY, 10000);// адрес и порт
    printf("--->tcp_bind_res=%d\n",res);
    tcp_arg(pcb, NULL);
    /* Change TCP state to LISTEN. */
     pcb =tcp_listen(pcb);  // дать серверу команду ожидания входящего подключения 
     printf("--->tcp_listen_res=%d\n",res);
    /* Set up http_accet() function to be called   when a new connection arrives. */
    tcp_accept(pcb, accept_callback); // к событию  привязать процедуру
    //tcp_recv(pcb, recv_callback);//&&&&&&&&&&&&&&&&&&&&&&&&&&&&????????????????????
}
//////////////////////////////////////////////////////////////////////////////;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


uint16 i=0;

void main()
{
 //for (i=0;i<1024;i++ )  Table[i] =i;//+++++++++++++++++++++++++++++++  

	struct netif netif;
	ip_addr_t ipaddr, netmask, gw;

	URT_Start();
	ETH_Start(); //ethernet SPI link
	ETW_Start(); //ethernet time wheel

	enc_init(epmSaneValues.macAddress);  //enc28j60  541

	if(epmSaneValues.u.bits.useDhcp) {
		g_ucFlags |= (1<<FLAG_USE_DHCP);
	  }

	LCD_Start(); 	LCD_Position(0,0);	LCD_PrintString("Hello all");

    ETW_StartEx(ETW_ISR);  //это  настраивает  адрес вектора прерывания 
    CyGlobalIntEnable;

	lwip_init();    // init.c  290

	if((g_ucFlags & (1<<FLAG_USE_DHCP)) == 0) {
        IP4_ADDR(&ipaddr,epmSaneValues.ipAddress[0], epmSaneValues.ipAddress[1], epmSaneValues.ipAddress[2], epmSaneValues.ipAddress[3]);
        IP4_ADDR(&netmask, epmSaneValues.netMask[0],  epmSaneValues.netMask[1],  epmSaneValues.netMask[2],  epmSaneValues.netMask[3]);
           IP4_ADDR(&gw,     epmSaneValues.gateWay[0], epmSaneValues.gateWay[1],  epmSaneValues.gateWay[2],  epmSaneValues.gateWay[3]);
	} else {
		IP4_ADDR(&ipaddr,  0, 0, 0, 0);
		IP4_ADDR(&netmask, 0, 0, 0, 0);
		IP4_ADDR(&gw,      0, 0, 0, 0);
	}
//------------------------------------------------------------------------------------------------------------------------------------------------
	netif_add(&netif, &ipaddr, &netmask, &gw, NULL, enc28j60_init, ethernet_input);
	netif_set_default(&netif);

	if(g_ucFlags & (1<<FLAG_USE_DHCP)) {
		dhcp_start(&netif);
	} else {
   // printf("-----------------netif_set_up\n");
		netif_set_up(&netif);   // проходит  gratuitous-запрос ссамому себе
	}

	unsigned long lastArpTime = 0, lastTcpTime = 0, lastDhcpCoarseTime = 0, lastDhcpFineTime = 0;
  //**************************************************************************************************************************************  
    tcp_init_func();    //стр 132   Create a new TCP; PCB адрес и порт; взвод  предварительный;   привязать процедуру

	while(1)
	{
		if((g_ulTickCounter - lastArpTime) >= (ARP_TMR_INTERVAL / TICK_MS)) {
			etharp_tmr();
            printf("main 278 tharp_tmr()\n");
			lastArpTime = g_ulTickCounter;
		}
        
		if((g_ulTickCounter - lastTcpTime) >= (TCP_TMR_INTERVAL / TICK_MS)) {
			tcp_tmr();
			lastTcpTime = g_ulTickCounter;
		}

        if(1) {
			enc_action(&netif);//  672__enc28j60.c   читаем пакет в  netif->input(p, netif);        It should be called when the ENC28J60 has signaled an interrupt
			//g_ucFlags &= ~(1<<FLAG_ENC_INT);
		      }
		heartbeat();
	}
}
/* [] END OF FILE */
